get_anomaly_score: Estimate anomaly-score for each value of each Key of a data...

Description Usage Arguments Value

View source: R/get_anomaly_score.R

Description

Estimate anomaly-score for each value of each Key of a data frame in three steps 1. Identification of Changepoints and subsequent segmentation of the time series 2. (Optional) Partly Normalization of Values of each Key 3. Estimating anomaly-score based on residuals of generalized-arma and (normal) arima-model plus remainder based on stl (time series decomposition) The user can control which kind of anomalies she is interested in regarding three dimensions: 1. speed: set normalize_weight and method_weights$garima to 0 in order to increase speed 2. global vs local anomalies: stl finds global outliers, arima and garima local outliers conditional on last values 3. balanced vs geometrical intuitive: garima-anomaly-score is generally symmetric distributed. Distribution of stl- and arima anomaly-scores depend on normalization beforehand. No normalization and right-skewed original data will lead to right-skewed anomaly-score-distribution here.

Usage

1
2
3
4
5
get_anomaly_score(
  df,
  method_weights = list(garima = 0.5, arima = 0.5, stl = 0),
  normalize_weight = 0
)

Arguments

df

data frame containing at least Columns Key, Date and Value

method_weights

List of Weights for calculation of overall anomaly-score. Setting garima = 0 significantly increases computational performance

normalize_weight

Share of Normalization. Only affects arima and stl. Setting to 0 singificantly increases computational performance

x.matrix

optional matrix of regressors, use to model seasonality

Value

List containing extended inputted df possessing method-specific and global anomaly-score, and input-params


td-berlin/anomalizer documentation built on Feb. 21, 2020, 2:03 a.m.